## 电影月度票房

接口：bo_monthly

描述：获取电影月度票房数据

数据更新：本月更新上一月数据

数据历史： 数据从2008年1月1日开始，超过10年历史数据。

数据权限：用户需要至少500积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期（每月1号，格式YYYYMMDD） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| name | str | Y | 影片名称 |
| list_date | str | Y | 上映日期 |
| avg_price | float | Y | 平均票价 |
| month_amount | float | Y | 当月票房（万） |
| list_day | int | Y | 月内天数 |
| p_pc | int | Y | 场均人次 |
| wom_index | float | Y | 口碑指数 |
| m_ratio | float | Y | 月度占比（%） |
| rank | int | Y | 排名 |

接口使用

```python
pro = ts.pro_api()
#或者
#pro = ts.pro_api('your token')

df = pro.bo_monthly(date='20180901')
```

数据示例

```python
date       name   list_date  avg_price  month_amount  list_day  p_pc  \
0   20180901  碟中谍6：全面瓦解  2018-08-31       37.0      104316.0        30    14   
```